---
height: 4
---

# Used tables

The table below assists with verifying if workflows and dashboards utilize legacy tables.

Each row:
- Points to a legacy table detected in the code using the code path, query or workflow & task reference;
- Provides the _lineage_ i.e. which `workflow -> task -> notebook...` execution sequence leads to that usage.

